@@ -229,7 +229,7 @@
 ##' out any transformation the options \code{trans = NULL} and
 ##' \code{inv = NULL} should be used.
 ##' @export
-##' @import mapproj hexbin mapdata maps
+##' @import mapproj hexbin maps
 ##' @return As well as generating the plot itself, \code{scatterPlot} also
 ##'   returns an object of class ``openair''. The object includes three main
 ##'   components: \code{call}, the command used to generate the plot;
@@ -1496,6 +1496,8 @@ add.map <- function (Args, ...) {
   if (Args$map.res == "default") {
     res <- "world"
   } else {
+    
+    try_require("mapdata", "scatterPlot")
     res <- "worldHires"       
   }
   
