@@ -192,10 +192,7 @@ timeProp <- function(mydata, pollutant = "nox", proportion = "cluster",
   # time zone of input data
   tzone <- attr(mydata$date, "tzone")
   
-  # make sure we have a full time series
-  mydata <- date.pad(mydata, type = type)
-  
-  # cut data
+   # cut data
   mydata <- cutData(mydata, c(type, proportion))
   
   # overall averages by time interval
@@ -264,7 +261,7 @@ timeProp <- function(mydata, pollutant = "nox", proportion = "cluster",
   attr(results$date, "tzone") <- tzone
   
   # join with aves to get date2
-  id <- which(is.na(results$wd))
+  id <- which(is.na(results[[proportion]]))
   if (length(id) > 0) results <- results[-id, ]
   results <- left_join(results, select_(aves, type, "date", "date2"), by = c(type, "date"))
   
